import type { AggregateOptions, Document, FindOptions } from 'mongodb';
import { ExplainPlan } from '@mongodb-js/explain-plan-helper';
import type AppRegistry from 'hadron-app-registry';
import type { DataService } from 'mongodb-data-service';
import type { Action, AnyAction, Reducer } from 'redux';
import type { ThunkAction } from 'redux-thunk';
export declare function isAction<A extends AnyAction>(action: AnyAction, type: A['type']): action is A;
export type SerializedExplainPlan = ReturnType<ExplainPlan['serialize']>;
export type ExplainPlanModalState = {
    namespace: string;
    isDataLake: boolean;
    error: string | null;
    isModalOpen: boolean;
    status: 'initial' | 'loading' | 'ready' | 'error';
    explainPlan: SerializedExplainPlan | null;
    rawExplainPlan: unknown | null;
    explainPlanFetchId: number;
};
type ExplainPlanDataService = Pick<DataService, 'explainAggregate' | 'explainFind' | 'isCancelError'>;
type ExplainPlanAppRegistry = Pick<AppRegistry, 'on' | 'emit'>;
type ExplainPlanModalExtraArgs = {
    dataService: ExplainPlanDataService;
    localAppRegistry?: ExplainPlanAppRegistry;
};
type ExplainPlanModalThunkAction<R, A extends Action = AnyAction> = ThunkAction<R, ExplainPlanModalState, ExplainPlanModalExtraArgs, A>;
export declare const reducer: Reducer<ExplainPlanModalState>;
type OpenExplainPlanModalEvent = {
    query: {
        filter: Document;
    } & Pick<FindOptions, 'projection' | 'collation' | 'sort' | 'skip' | 'limit' | 'maxTimeMS'>;
    aggregation?: never;
} | {
    query?: never;
    aggregation: {
        pipeline: Document[];
        collation?: AggregateOptions['collation'];
        maxTimeMS?: number;
    };
};
export declare const openExplainPlanModal: (event: OpenExplainPlanModalEvent) => ExplainPlanModalThunkAction<Promise<void>>;
export declare const closeExplainPlanModal: () => ExplainPlanModalThunkAction<void>;
export declare const openCreateIndexModal: () => ExplainPlanModalThunkAction<void>;
export type ExplainPlanModalConfigureStoreOptions = {
    localAppRegistry: ExplainPlanAppRegistry;
    dataProvider?: {
        dataProvider?: ExplainPlanDataService;
    };
    namespace: string;
    isDataLake: boolean;
};
export declare function configureStore({ localAppRegistry, dataProvider, namespace, isDataLake, }: ExplainPlanModalConfigureStoreOptions): import("redux").Store<ExplainPlanModalState, AnyAction> & {
    dispatch: import("redux-thunk").ThunkDispatch<any, {
        dataService: ExplainPlanDataService;
        localAppRegistry: ExplainPlanAppRegistry;
    }, AnyAction>;
};
export {};
//# sourceMappingURL=explain-plan-modal-store.d.ts.map